<?php
/* $Id: spanish-iso-8859-1.inc.php,v 2.83 2005/06/12 10:10:10 swix Exp $ */

$charset = 'iso-8859-1';
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// Atajos para Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Dom', 'Lun', 'Mar', 'Mie', 'Jue', 'Vie', 'Sab');
$month = array('Ene', 'Feb', 'Mar', 'Abr', 'May', 'Jun', 'Jul', 'Ago', 'Sep', 'Oct', 'Nov', 'Dic');
// Ver http://www.php.net/manual/es/function.strftime.php para definir
// la variable siguiente
$datefmt = '%d-%m-%Y a las %H:%M:%S';
$timespanfmt = '%s das, %s horas, %s minutos y %s segundos';

// Daniel Hinostroza 3.4.2005: los de abajo y string = cadena de caracteres

$strAPrimaryKey = 'Se aadi una clave primaria en %s';
$strAbortedClients = 'Abortado';
$strAbsolutePathToDocSqlDir = 'Por favor, ingrese la ruta absoluta del servidor hacia el directorio docSQL';
$strAccessDenied = 'Acceso denegado ';
$strAccessDeniedExplanation = 'phpMyAdmin intent conectarse con el servidor MySQL, y el servidor rechaz esta conexin. Deber revisar el host, nombre de usuario y contrasea en config.inc.php y asegurarse que corresponden con la informacin dada por el administrador del servidor MySQL.';
$strAction = 'Accin';
$strAddAutoIncrement = 'Aada el valor AUTO_INCREMENT';
$strAddConstraints = 'Aada constreimientos';
$strAddDeleteColumn = 'Aadir/borrar columna de criterio';
$strAddDeleteRow = 'Aadir/borrar fila de criterio';
$strAddDropDatabase = 'Aada DROP DATABASE';
$strAddFields = 'Aada %s campo(s)';
$strAddHeaderComment = 'Aada su propio comentario en el encabezado (\\n segmenta las oraciones)';
$strAddIfNotExists = 'Aada en CASO DE NO EXISTIR';
$strAddIntoComments = 'Aada en los comentarios';
$strAddNewField = 'Insertar nuevo campo';
$strAddPrivilegesOnDb = 'Aada privilegios en esta base de datos';
$strAddPrivilegesOnTbl = 'Aada privilegios en esta tabla';
$strAddSearchConditions = 'Insertar las condiciones de bsqueda (cuerpo de la clusula "where"):';
$strAddToIndex = 'Aadido al ndice &nbsp;%s&nbsp;columna(s)';
$strAddUser = 'Agregar nuevo usuario';
$strAddUserMessage = 'Ud. ha agregado un nuevo usuario.';
$strAddedColumnComment = 'Se aadi un comentario para la columna';
$strAddedColumnRelation = 'Se aadi una relacin para la columna';
$strAdministration = 'Administracin';
$strAffectedRows = 'Filas afectadas: ';
$strAfter = 'Despus de %s';
$strAfterInsertBack = 'Volver';
$strAfterInsertNewInsert = 'Insertar un nuevo registro';
$strAfterInsertNext = 'Edite la siguiente fila';
$strAfterInsertSame = 'Volver a esta pgina';
$strAll = 'Todos/as';
$strAllTableSameWidth = 'Mostrar todas las tablas que tienen el mismo ancho?';
$strAlterOrderBy = 'Modificar el "Order By" de la tabla';
$strAnIndex = 'Se aadi un ndice en %s';
$strAnalyzeTable = 'Analizar la tabla';
$strAnd = 'y luego';
$strAny = 'cualquiera';
$strAnyHost = 'Cualquier servidor';
$strAnyUser = 'Cualquier usuario';
$strApproximateCount = 'Podra ser aproximado.  Lase la FAQ 3.11';
$strArabic = 'rabe';
$strArmenian = 'Armenio';
$strAscending = 'Ascendente';
$strAtBeginningOfTable = 'Al comienzo de la tabla';
$strAtEndOfTable = 'Al final de la tabla';
$strAttr = 'Atributos';
$strAutodetect = 'Autodetecte';
$strAutomaticLayout = 'Layout automtico';

$strBack = 'Volver';
$strBaltic = 'Bltico';
$strBeginCut = 'INICIO DEL CORTE';
$strBeginRaw = 'INICIO DEL VOLCADO';
$strBinLogEventType = 'Tipo de evento';
$strBinLogInfo = 'Informacin';
$strBinLogName = 'Nombre con el cual se registr';
$strBinLogOriginalPosition = 'Posicin original';
$strBinLogPosition = 'Posicin';
$strBinLogServerId = 'ID del servidor';
$strBinary = ' Binario ';
$strBinaryDoNotEdit = ' Binario - no editar! ';
$strBinaryLog = 'Log binario';
$strBookmarkAllUsers = 'Permitir que todo usuario pueda acceder a este bookmark';
$strBookmarkDeleted = 'El "bookmark" ha sido borrado.';
$strBookmarkLabel = 'Etiqueta';
$strBookmarkOptions = 'Opciones de bookmark';
$strBookmarkQuery = 'Consulta guardada en favoritos';
$strBookmarkThis = 'Guardar esta consulta en favoritos';
$strBookmarkView = 'Solamente ver';
$strBrowse = 'Examinar';
$strBrowseForeignValues = 'Muestre los valores extranjeros';
$strBufferPool = 'Total de memoria del bfer'; 
$strBufferPoolActivity = 'Actividad del memoria (bfer) de trnsito comn';
$strBufferPoolUsage = 'Consumo del Total de memoria del bfer'; 
$strBufferReadMisses = 'Lea los fallos';
$strBufferReadMissesInPercent = 'Lea los fallos en %';
$strBufferWriteWaits = 'Escriba las esperas';
$strBufferWriteWaitsInPercent = 'Escriba las esperas en %';
$strBulgarian = 'Blgaro';
$strBusyPages = 'Pginas activas'; 
$strBzError = 'Si desea usar las opciones de compresin Bz2, deber actualizar su php a una versin ms reciente. phpMyAdmin no fue capaz de comprimir el dump debido a que est daada la extensin Bz2 en esta versin de php. Le recomendamos que cambie el parmetro <code>$cfg[\'BZipDump\']</code> en su archivo de configuracin phpMyAdmin a <code>FALSE</code>. Lea el reporte de "bugs" de php %s para mayor informacin.';
$strBzip = '"Comprimido con bzip"';

$strCSVOptions = 'Opciones CSV';
$strCalendar = 'Calendario';
$strCannotLogin = 'No se consigui hacer login al servidor MySQL';
$strCantLoad = 'no se pudo cargar la extensin %s,<br />por favor revise su configuracin de PHP.';
$strCantLoadRecodeIconv = 'No se puede cargar iconv o recodificar una extensin necesaria para la conversin de juegos de caracteres, configure php para permitir el uso de estas extensiones o desactive la conversin de juegos de caracteres en phpMyAdmin.';
$strCantRenameIdxToPrimary = 'No puede cambiar el nombre del ndice a PRIMARY!';
$strCantUseRecodeIconv = 'No se puede utilizar iconv ni libiconv ni la funcin recode_string mientras se carga la extensin de informes. Comprueba la configuracin de php.';
$strCardinality = 'Cardinalidad';
$strCarriage = 'Retorno de carro: \\r';
$strCaseInsensitive = 'independiente de maysculas y minsculas';
$strCaseSensitive = 'dependiente de maysculas y minsculas';
$strCentralEuropean = 'Europeo central';
$strChange = 'Cambiar';
$strChangeCopyMode = 'Crear un nuevo usuario con los mismos privilegios y...';
$strChangeCopyModeCopy = '... mantenga el anterior.';
$strChangeCopyModeDeleteAndReload = ' ... borre el viejo de las tablas de usuario y luego recargue los privilegios.';
$strChangeCopyModeJustDelete = ' ... borre el viejo de las tablas de usuario.';
$strChangeCopyModeRevoke = ' ... revocar todos los privilegios activos del viejo y elimnelos despus.';
$strChangeCopyUser = 'Cambie la informacin de Login / Copiar Usuario';
$strChangeDisplay = 'Elija el campo a mostrar';
$strChangePassword = 'Cambio de contrasea';
$strCharset = 'Juego de caracteres';
$strCharsetOfFile = 'Juego de caracteres del archivo:'; 
$strCharsets = 'Juegos de caracteres'; 
$strCharsetsAndCollations = 'Juego de caracteres y sus cotejamientos (collations)'; 
$strCheckAll = 'Revisar todos/as';
$strCheckOverhead = 'Revise las tablas con residuo a depurar (overhead)';
$strCheckPrivs = 'Revise los privilegios';
$strCheckPrivsLong = 'Revise los privilegios para la base de datos &quot;%s&quot;.';
$strCheckTable = 'Revisar tabla';
$strChoosePage = 'Elija la pgina a editar';
$strColComFeat = 'Mostrando los comentarios de la columna';
$strCollation = 'Collation';
$strColumnNames = 'Nombre de las columnas';
$strColumnPrivileges = 'Privilegios especficos para la columna';
$strCommand = 'Comando';
$strComments = 'Comentarios';
$strCommentsForTable = 'COMENTARIOS PARA LA TABLA';
$strCompatibleHashing = 'Compatible con MySQL&nbsp;4.0';
$strCompleteInserts = 'Completar los "Inserts"';
$strCompression = 'Compresin';
$strConfigFileError = 'phpMyAdmin no puede leer el fichero de configuracin!<br />Esto puede suceder si php encuentra un error sintctico en l o bien php no puede encontrar el fichero.<br />Intente acceder al fichero de configuracin directamente mediante el siguiente enlace y compruebe el(los) mensaje(s) de error que reciba. En muchas ocasiones falta una coma o punto y coma en algn sitio.<br />Si recibe una pgina en blanco, todo est correcto.';
$strConfigureTableCoord = 'Configure las coordenadas para la tabla %s';
$strConnectionError = 'No se estableci la conexin: los parmetros estn incorrectos.';
$strConnections = 'Conexiones';
$strConstraintsForDumped = 'Filtros para las tablas descargadas (dump)';
$strConstraintsForTable = 'Filtros para la tabla';
$strCookiesRequired = 'Las "cookies" deben estar habilitadas pasado este punto.';
$strCopyDatabaseOK = 'La base de datos %s ha sido copiada a %s';
$strCopyTable = 'Copiar la tabla a (base de datos<b>.</b>tabla):';
$strCopyTableOK = 'La tabla %s se copi a %s.';
$strCopyTableSameNames = 'No es posible copiar la tabla a la misma!';
$strCouldNotKill = 'phpMyAdmin no fue capaz de destruir el thread %s. Probablemente ya ha sido cerrado.';
$strCreate = 'Crear';
$strCreateIndex = 'Crear un ndice en&nbsp;%s&nbsp;columnas';
$strCreateIndexTopic = 'Crear un nuevo ndice';
$strCreateNewDatabase = 'Crear nueva base de datos';
$strCreateNewTable = 'Crear nueva tabla en la base de datos %s';
$strCreatePage = 'Crear una nueva pgina';
$strCreatePdfFeat = 'Creacin de los PDF';
$strCreationDates = 'Fechas de creacin/actualizacin/revisin';
$strCriteria = 'Criterio';
$strCroatian = 'Croata';
$strCyrillic = 'Cirlico';
$strCzech = 'Checo';
$strCzechSlovak = 'Checo-Eslovaco';

$strDBComment = 'Comentario de la base de datos: ';
$strDBCopy = 'Copie la base de datos a';
$strDBGContext = 'Contexto';
$strDBGContextID = 'ID del contexto';
$strDBGHits = 'Hits';
$strDBGLine = 'Lnea';
$strDBGMaxTimeMs = 'Tiempo mximo, ms';
$strDBGMinTimeMs = 'Tiempo mnimo, ms';
$strDBGModule = 'Mdulo';
$strDBGTimePerHitMs = 'Tiempo/Hit, ms';
$strDBGTotalTimeMs = 'Tiempo total, ms';
$strDBRename = 'Cambiar el nombre de la base de datos a';
$strDanish = 'Dans';
$strData = 'Datos';
$strDataDict = 'Diccionario Datos';
$strDataOnly = 'Solamente datos';
$strDataPages = 'Pginas que contienen datos'; 
$strDatabase = 'Base de datos';
$strDatabaseEmpty = 'El nombre de la base de datos est vaca!';
$strDatabaseExportOptions = 'Opciones de exportacin de la base de datos';
$strDatabaseHasBeenDropped = 'La base de datos %s ha sido eliminada.';
$strDatabaseNoTable = 'Esta base de datos no contiene tablas!';
$strDatabases = 'Bases de datos';
$strDatabasesDropped = '%s bases de datos han sido eliminadas exitosamente.';
$strDatabasesStats = 'Estadsticas de la base';
$strDatabasesStatsDisable = 'Desactive las estadsticas';
$strDatabasesStatsEnable = 'Active las estadsticas';
$strDatabasesStatsHeavyTraffic = 'Nota: Activando las estadsticas de la base de datos aqu podran causar trfico pesado entre el servidor web y el servidor MySQL.';
$strDbPrivileges = 'Privilegios especficos para la base de datos';
$strDbSpecific = 'especfico para la base de datos';
$strDefault = 'Predeterminado';
$strDefaultEngine = '%s es el motor de almacenamiento predeterminado en este servidor MySQL.';
$strDefaultValueHelp = 'Para valores predeterminados, por favor ingrese solamente un valor, sin "escaping backslash" ni comillas, usando este formato: a';
$strDefragment = 'Defragmentar la tabla';
$strDelOld = 'La pgina actual tiene referencias a tablas que ya no existen.  Desea eliminar esas referencias?';
$strDelayedInserts = 'Use "inserts" con retraso';
$strDelete = 'Borrar';
$strDeleteAndFlush = 'Borre a los usuarios y vuelva a cargar los privilegios posteriormente.';
$strDeleteAndFlushDescr = 'Este es el modo ms limpio, pero volver a cargar los privilegios puede tomar tiempo.';
$strDeleted = 'La fila se ha borrado';
$strDeletedRows = 'Filas borradas: ';
$strDeleting = 'Borrando %s';
$strDescending = 'Descendente';
$strDescription = 'Descripcin';
$strDictionary = 'diccionario';
$strDirtyPages = 'Pginas que requieren ser depuradas'; 
$strDisableForeignChecks = 'Deshabilitar la revisin de las llaves extranjeras (foreign keys)';
$strDisabled = 'Deshabilitado';
$strDisplayFeat = 'Mostrar las opciones';  //Features = opciones, componentes?
$strDisplayOrder = 'Mostrar en este orden:';
$strDisplayPDF = 'Mostrar esquema PDF';
$strDoAQuery = 'Hacer una consulta (comodn: "%")';
$strDoYouReally = 'Realmente desea ';
$strDocu = 'Documentacin';
$strDrop = 'Eliminar';
$strDropDatabaseStrongWarning = 'Usted est a punto de DESTRUIR una base de datos completa!';
$strDropSelectedDatabases = 'Elimine la base de datos seleccionada';
$strDropUsersDb = 'Eliminar las bases de datos que tienen los mismos nombres de los usuarios.';
$strDumpSaved = 'Su archivo (MySQL dump) ha sido guardado con el nombre %s.';
$strDumpXRows = 'Volcar %s filas empezando por la fila %s.';
$strDumpingData = 'Volcar la base de datos para la tabla';
$strDynamic = 'dinmico/a';

$strEdit = 'Editar';
$strEditPDFPages = 'Editar las pginas PDF';
$strEditPrivileges = 'Editar los privilegios';
$strEffective = 'Efectivo/a';
$strEmpty = 'Vaciar';
$strEmptyResultSet = 'MySQL ha devuelto un valor vaco (i.e. cero columnas).';
$strEnabled = 'Habilitado';
$strEncloseInTransaction = 'Incluya lo exportado en una transaccin';
$strEnd = 'Fin';
$strEndCut = 'FIN DEL CORTE';
$strEndRaw = 'FIN DEL VOLCADO';
$strEngineAvailable = '%s est disponible en este servidor MySQL.';
$strEngineDisabled = '%s ha sido deshabilitado para este motor de almacenamiento.';
$strEngineUnsupported = 'Este servidor MySQL no es compatible con el motor de almacenamiento %s.'; 
$strEngines = 'Motores';
$strEnglish = 'Ingls';
$strEnglishPrivileges = ' Nota: Los nombres de los privilegios de MySQL estn expresados en ingls ';
$strError = 'Error';
$strEscapeWildcards = 'Los comodines _ y % deben acompaarse de \ para usarlos de manera literal';
$strEstonian = 'Estonio';
$strExcelEdition = 'Edicin Excel';
$strExcelOptions = 'Opciones de Excel';
$strExecuteBookmarked = 'Ejecute la consulta marcada previamente';
$strExplain = 'Explicar el SQL';
$strExport = 'Exportar';
$strExtendedInserts = '"Inserts" extendidos';
$strExtra = 'Extra';

$strFailedAttempts = 'Intentos fallidos';
$strField = 'Campo';
$strFieldHasBeenDropped = 'Se elimin el campo %s';
$strFields = 'Campos';
$strFieldsEmpty = 'El nmero de campos est vaco!';
$strFieldsEnclosedBy = 'Campos encerrados por';
$strFieldsEscapedBy = 'Campos escapados por';
$strFieldsTerminatedBy = 'Campos terminados en';
$strFileAlreadyExists = 'El archivo %s ya existe en el servidor, cambie el nombre del archivo o revise la opcin de sobreescritura.';
$strFileCouldNotBeRead = 'No fue posible leer el archivo';
$strFileNameTemplate = 'Plantilla del nombre del archivo';
$strFileNameTemplateHelp = 'Use __DB__ para conservar el nombre de la base de datos, __TABLE__ para usar el nombre de la tabla y las opciones %sany strftime%s para especificaciones de tiempo; la extensin (.sql, .cvs, etc.) se aadir automticamente. Cualquier otro texto ser conservado.';
$strFileNameTemplateRemember = 'recuerde la plantilla';
$strFixed = 'fijo';
$strFlushPrivilegesNote = 'Nota: phpMyAdmin obtiene los privilegios de los usuarios \'directamente de las tablas de privilegios MySQL\'. El contenido de estas tablas puede diferir de los privilegios que usa el servidor si es que se han realizado cambios manuales en l. En este caso, deber %scargar la pgina de privilegios nuevamente%s antes de continuar.';
$strFlushTable = 'Vaciar el cach de la tabla ("FLUSH")';
$strFormEmpty = 'Falta un valor en el formulario!';
$strFormat = 'Formato';
$strFreePages = 'Pginas libres'; 
$strFullText = 'Textos completos';
$strFunction = 'Funcin';

$strGenBy = 'Generado por';
$strGenTime = 'Tiempo de generacin';
$strGeneralRelationFeat = 'Opciones de relacin general';  //Features = opciones, componentes?
$strGeorgian = 'Georgiano';
$strGerman = 'Alemn';
$strGlobal = 'global';
$strGlobalPrivileges = 'Privilegios globales';
$strGlobalValue = 'Valor global';
$strGo = 'Contine';
$strGrantOption = 'Conceder';
$strGreek = 'Griego';
$strGzip = '"Comprimido con gzip"';

$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Opciones de exportacin Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Opciones de exportacin Microsoft Word 2000';
$strHasBeenAltered = 'fue modificada.';
$strHasBeenCreated = 'se cre.';
$strHaveToShow = 'Debe elegir al menos una columna para mostrar';
$strHebrew = 'Hebreo';
$strHexForBinary = 'Use hexadecimal para campos binarios';
$strHome = 'Pgina de inicio';
$strHomepageOfficial = 'Pgina oficial de phpMyAdmin';
$strHost = 'Servidor';
$strHostEmpty = 'El nombre del servidor est vaco!!';
$strHungarian = 'Hngaro';

$strIcelandic = 'Islands';
$strId = 'Identificacin';
$strIdxFulltext = 'Texto completo';
$strIfYouWish = 'Si desea cargar solamente una de las columnas de la tabla, especifquela, separando los campos con una coma.';
$strIgnore = 'Ignorar';
$strIgnoreInserts = 'Use la opcin ignore inserts';
$strIgnoringFile = 'Ignorando el archivo %s';
$strImportDocSQL = 'Importar archivos docSQL';
$strImportFiles = 'Importar archivos';
$strImportFinished = 'Importacin culminada';
$strInUse = 'en uso';
$strIndex = 'ndice';
$strIndexHasBeenDropped = 'El ndice %s ha sido eliminado';
$strIndexName = 'Nombre del ndice&nbsp;:';
$strIndexType = 'Tipo de ndice&nbsp;:';
$strIndexWarningMultiple = 'Se cre ms de una clave %s para la columna `%s`';
$strIndexWarningPrimary = 'Las claves PRIMARIA e INDICE no deben seleccionarse juntas para la columna `%s`';
$strIndexWarningTable = 'Problemas con los ndices de la tabla `%s`';
$strIndexWarningUnique = 'Las claves UNICA e INDICE no deben seleccionarse juntas para la columna `%s`';
$strIndexes = 'ndices';
$strInnoDBAutoextendIncrement = 'Incremente el valor Autoextend'; 
$strInnoDBAutoextendIncrementDesc = 'El tamao a incrementar para que se extienda el ancho de una tabla capaz de autoextenderse cuando se llena.'; 
$strInnoDBBufferPoolSize = 'Tamao de la memoria (bfer) de trnsito comn';
$strInnoDBBufferPoolSizeDesc = 'El tamao del de memoria intermedia (bfer) usado por InnoDB para almacenar, en el cache, los datos e ndices de sus tablas.';
$strInnoDBDataFilePath = 'Archivos de datos'; 
$strInnoDBDataHomeDir = 'Directorio raz de los datos';
$strInnoDBDataHomeDirDesc = 'La parte constante de la ruta del directorio para todos los archivos de datos InnoDB.'; 
$strInnoDBPages = 'pginas';
$strInnodbStat = 'Estado del InnoDB';
$strInsecureMySQL = 'Su archivo de configuracin contiene parmetros (root sin contrasea) que corresponden a la cuenta privilegiada predeterminada de MySQL. Su servidor de MySQL est usando estos valores, que constituyen una vulnerabilidad.  Se le recomienda corregir esta brecha de seguridad.';
$strInsert = 'Insertar';
$strInsertAsNewRow = 'Insertar como una nueva fila';
$strInsertBookmarkTitle = 'Por favor, inserte un ttulo para el bookmark';
$strInsertNewRow = 'Insertar nueva fila';
$strInsertTextfiles = 'Insertar archivo de texto en la tabla';
$strInsertedRowId = 'Se insert la id de la fila:';
$strInsertedRows = 'Filas insertadas:';
$strInstructions = 'Instrucciones';
$strInternalNotNecessary = '* No es necesaria una relacin interna cuando tambin existe en InnoDB.';
$strInternalRelations = 'Relaciones internas';

$strJapanese = 'Japons';
$strJumpToDB = 'Salte a la base de datos &quot;%s&quot;.';
$strJustDelete = 'Solamente borre a los usuarios de la tabla de privilegios.';
$strJustDeleteDescr = 'Los usuarios &quot;borrados&quot; an podrn acceder al servidor de manera usual hasta que los privilegios se hayan vuelto a cargar.';

$strKeepPass = 'No cambiar la contrasea';
$strKeyname = 'Nombre de la clave';
$strKill = 'Matar el proceso';
$strKorean = 'Coreano';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'opciones LaTeX';
$strLandscape = 'Orientacin horizontal';
$strLatchedPages = 'Pginas vinculadas';
$strLatexCaption = 'Subtitulado de la tabla';
$strLatexContent = 'Contenido de la tabla __TABLE__';
$strLatexContinued = '(contina)';
$strLatexContinuedCaption = 'Continuacin del subtitulado de la tabla';
$strLatexIncludeCaption = 'Incluya subtitulado de la tabla';
$strLatexLabel = 'Clave de la etiqueta';
$strLatexStructure = 'Estructura de la tabla __TABLE__';
$strLatvian = 'Letn';
$strLengthSet = 'Longitud/Valores*';
$strLimitNumRows = 'registros por pgina';
$strLineFeed = 'Retorno de carro: \\n';
$strLinesTerminatedBy = 'Lneas terminadas en';
$strLinkNotFound = 'No se encontr el enlace';
$strLinksTo = 'Enlaces a';
$strLithuanian = 'Lituano';
$strLoadExplanation = 'El mejor mtodo es revisado en forma predeterminada, pero puede cambiarlo si fracasa.';
$strLoadMethod = 'Mtodo de carga de datos';
$strLocalhost = 'Local';
$strLocationTextfile = 'Localizacin del archivo de texto';
$strLogPassword = 'Contrasea:';
$strLogServer = 'Servidor';
$strLogUsername = 'Usuario:';
$strLogin = 'Identificacin';
$strLoginInformation = 'Informacin acerca del login';
$strLogout = 'Salir';
$strLongOperation = 'Esta operacin podra tomar algn tiempo. Procedo de todas formas?';

$strMIMETypesForTable = 'MIME TYPES PARA LA TABLA';
$strMIME_MIMEtype = 'MIME-type';
$strMIME_available_mime = 'MIME-types disponibles';
$strMIME_available_transform = 'Transformaciones disponibles';
$strMIME_description = 'Descripcin';
$strMIME_nodescription = 'No hay una descripcin disponible para esta transformacin.<br />Por favor pregunte al autor lo que %s hace.';
$strMIME_transformation = 'Transformacin del navegador';
$strMIME_transformation_note = 'Para una lista de opciones de transformacin disponibles y sus transformaciones MIME-type transformations, d clic en %stransformation descriptions%s';
$strMIME_transformation_options = 'Opciones de transformacin';
$strMIME_transformation_options_note = 'Por favor ingrese los valores para las opciones de transformacin usando este formato: \'a\',\'b\',\'c\'...<br />Si alguna vez requiere insertar un Backslash ("\") o comilla sencilla ("\'") entre esos valores, use backslash (por ejemplo \'\\\\xyz\' o \'a\\\'b\').';
$strMIME_without = 'MIME-types impresos en itlicas no tienen una funcin de transformacin adicional';
$strMaximumSize = 'Tamao mximo: %s%s';
$strMbExtensionMissing = 'No se hall la extensin PHP mbstring y al parecer usted est usando tipografa multibyte. phpMyAdmin no puede cortar correctamente las cadenas de caracteres sin la extensin mbstring y podra dar resultados inesperados.';
$strMbOverloadWarning = 'Usted ha activado mbstring.func_overload en su configuracin PHP. Esta opcin es incompatible con phpMyAdmin y podra causar la prdida de algunos datos!';
$strModifications = 'Se han guardado las modificaciones';
$strModify = 'Modificar';
$strModifyIndexTopic = 'Modificar un ndice';
$strMoreStatusVars = 'Ms variables del estado actual';
$strMoveTable = 'Mover tabla a (Base de datos<b>.</b>tabla):';
$strMoveTableOK = 'La tabla %s ha sido movida a %s.';
$strMoveTableSameNames = 'No es posible mover la tabla a la misma!';
$strMultilingual = 'multilinge';
$strMustSelectFile = 'Debe seleccionar el archivo que desea insertar.';
$strMyISAMDataPointerSize = 'Tamao del puntero de datos';
$strMyISAMDataPointerSizeDesc = 'El tamao predeterminado del puntero de datos en bytes, para su uso en CREATE TABLE para las tablas MyISAM cuando no se ha especificado la opcin MAX_ROWS.';
$strMyISAMMaxExtraSortFileSize = 'Tamao mximo de los archivos temporales durante la generacin del ndice'; 
$strMyISAMMaxExtraSortFileSizeDesc = 'Si el archivo temporal usado para la generacin rpida de ndices MyISAM fuese mayor que el uso del key cache por la cantidad especificada aqu, prefiera el mtodo key cache.';
$strMyISAMMaxSortFileSize = 'Tamao mximo para los archivos temporales generados durante la organizacin';
$strMyISAMMaxSortFileSizeDesc = 'El tamao mximo del archivo temporal que MySQL puede generar mientras genera un nuevo ndice MyISAM of the temporary file (durante REPAIR TABLE, ALTER TABLE, o LOAD DATA INFILE).';
$strMyISAMRecoverOptions = 'Modalidad de recuperacin automtica';
$strMyISAMRecoverOptionsDesc = 'La modalidad para la recuperacin automtica de tablas MyISAM cadas catastrficamente, como fuera determinado mediante la opcin al arranque del servidor --myisam-recover.'; 
$strMyISAMRepairThreads = 'Reparar los threads'; 
$strMyISAMRepairThreadsDesc = 'Si este valor es superior a 1, se generan los ndices de las tablas MyISAM en paralelo (cada ndice con su propio thread) durante el proceso Repare mediante organizacin.';
$strMyISAMSortBufferSize = 'Organizar el tamao del bfer de memoria';
$strMyISAMSortBufferSizeDesc = 'La cantidad de memoria que se asigna para organizar los ndices MyISAM durante la operacin REPAIR TABLE o cuando se generan ndices con CREATE INDEX o ALTER TABLE.';
$strMySQLCharset = 'Juegos de caracteres de MySQL';
$strMySQLConnectionCollation = 'Cotejamiento (collation) de las conexiones MySQL';
$strMySQLReloaded = 'Reinicio de MySQL.';
$strMySQLSaid = 'MySQL ha dicho: ';
$strMySQLServerProcess = 'MySQL %pma_s1% ejecutndose en %pma_s2% como %pma_s3%';
$strMySQLShowProcess = 'Mostrar procesos';
$strMySQLShowStatus = 'Mostrar informacin de marcha de MySQL';
$strMySQLShowVars = 'Mostrar las variables del sistema MySQL';

$strName = 'Nombre';
$strNeedPrimaryKey = 'Usted debe definir una llave primaria para esta tabla.';
$strNext = 'Prxima';
$strNo = 'No';
$strNoActivity = 'No ha habido actividad desde hace %s o ms segundos, por favor reingrese al sitio';
$strNoDatabases = 'No hay bases de datos';
$strNoDatabasesSelected = 'No se seleccionaron bases de datos.';
$strNoDescription = 'Sin descripcin';
$strNoDetailsForEngine = 'No existe informacin detallada acerca de las condiciones en que se encuentra este motor de almacenamiento.';
$strNoDropDatabases = '"DROP DATABASE" los enunciados ("sentences") estn deshabilitados.';
$strNoExplain = 'Saltarse la explicacin del SQL';
$strNoFrames = 'phpMyAdmin funciona mejor con un navegador que <b>soporte marcos (frames)</b>.';
$strNoIndex = 'No se ha definido el ndice!';
$strNoIndexPartsDefined = 'No se han definido las partes del ndice!';
$strNoModification = 'Sin cambios';
$strNoOptions = 'Este formato no tiene opciones';
$strNoPassword = 'Sin contrasea';
$strNoPermission = 'El servidor web no tiene permiso para guardar el archivo %s.';
$strNoPhp = 'Sin cdigo PHP';
$strNoPrivileges = 'Sin privilegios';
$strNoQuery = 'No existe la consulta SQL!';
$strNoRights = 'Usted no tiene suficientes privilegios para estar aqu ahora!';
$strNoRowsSelected = 'No se seleccionaron filas';
$strNoSpace = 'No hay suficiente espacio para guardar el archivo %s.';
$strNoTablesFound = 'No se han encontrado tablas en la base de datos.';
$strNoThemeSupport = 'No existe soporte para Temas, por favor, revise su configuracin y/o sus temas en el directorio %s.';
$strNoUsersFound = 'Usuario(s) no encontrado(s).';
$strNoValidateSQL = 'Saltarse la validacin del SQL';
$strNone = 'Ninguna';
$strNotNumber = 'sto no es un nmero!';
$strNotOK = 'no recibi el OK';
$strNotSet = 'La tabla <b>%s</b> no fue hallada o no fue definida en %s';
$strNotValidNumber = 'no es un nmero de fila vlido!';
$strNull = 'Nulo';
$strNumSearchResultsInTable = '%s resultado(s) en la tabla <i>%s</i>';
$strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> resultado(s)';
$strNumTables = 'Tablas';

$strOK = 'OK';
$strOftenQuotation = 'Usualmente son comillas. OPCIONAL significa que nicamente los campos char y varchar sern encerrados por "comillas".';
$strOperations = 'Operaciones';
$strOperator = 'Operador';
$strOptimizeTable = 'Optimizar la tabla';
$strOptionalControls = 'Es opcional. Controla el modo de escribir o leer caracteres especiales.';
$strOptionally = 'OPCIONAL';
$strOr = 'O';
$strOverhead = 'Residuo a depurar';
$strOverwriteExisting = 'Sobreescribir el(los) archivo(s) existente(s)';

$strPHP40203 = 'Usted est usando PHP 4.2.3, el cual tiene un error de codificacin en cuanto a las "cadenas de caracteres multi-byte" (mbstring). Lea el reporte 19404 de PHP. No se recomienda el uso de phpMyAdmin con esta versin de PHP.';
$strPHPVersion = 'Versin de PHP';
$strPageNumber = 'Nmero de pgina:';
$strPagesToBeFlushed = 'Pginas que sern eliminadas'; 
$strPaperSize = 'Tamao del papel';
$strPartialText = 'Textos parciales';
$strPassword = 'Contrasea';
$strPasswordChanged = 'La contrasea para %s se cambi exitosamente.';
$strPasswordEmpty = 'La contrasea est vaca!';
$strPasswordHashing = 'Hashing de la contrasea';
$strPasswordNotSame = 'Las contraseas no coinciden!';
$strPdfDbSchema = 'Esquema de la base de datos "%s" - Pgina %s';
$strPdfInvalidTblName = 'La tabla "%s" no existe!';
$strPdfNoTables = 'No existen tablas';
$strPerHour = 'por hora';
$strPerMinute = 'por minuto';
$strPerSecond = 'por segundo';
$strPersian = 'Persa';
$strPhoneBook = 'directorio telefnico';
$strPhp = 'Crear cdigo PHP';
$strPmaDocumentation = 'Documentacin de phpMyAdmin';
$strPmaUriError = 'La directiva <tt>$cfg[\'PmaAbsoluteUri\']</tt> DEBE constar en el fichero de configuracin!';
$strPolish = 'Polaco';
$strPortrait = 'Orientacin vertical';
$strPos1 = 'Empezar';
$strPrevious = 'Previo';
$strPrimary = 'Primaria';
$strPrimaryKeyHasBeenDropped = 'La clave primaria ha sido eliminada';
$strPrimaryKeyName = 'El nombre de la clave primaria debe ser... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>debe</b> ser el nombre de y <b>nicamente de</b> una clave primaria!)';
$strPrint = 'Imprimir';
$strPrintView = 'Vista de impresin';
$strPrintViewFull = 'Previsualizacin para imprimir (documento completo)';
$strPrivDescAllPrivileges = 'Incluye todos los privilegios excepto CONCEDER (GRANT).';
$strPrivDescAlter = 'Permite alterar la estructura de las tablas existentes.';
$strPrivDescCreateDb = 'Permite crear nuevas bases de datos y tablas.';
$strPrivDescCreateTbl = 'Permite la creacin de tablas nuevas.';
$strPrivDescCreateTmpTable = 'Permite la creacin de tablas temporales.';
$strPrivDescDelete = 'Permite borrar datos.';
$strPrivDescDropDb = 'Permite eliminar bases de datos y tablas.';
$strPrivDescDropTbl = 'Permite eliminar tablas.';
$strPrivDescExecute = 'Permite correr procedimientos guardados; no tiene efecto en esta versin de MySQL.';
$strPrivDescFile = 'Permite importar y exportar datos de y hacia archivos.';
$strPrivDescGrant = 'Permite aadir usuarios y privilegios sin conectarse nuevamente a la tabla de privilegios.';
$strPrivDescIndex = 'Permite crear y eliminar ndices.';
$strPrivDescInsert = 'Permite insertar y reemplazar datos.';
$strPrivDescLockTables = 'Permite poner candados a las tablas para el "thread" actual.';
$strPrivDescMaxConnections = 'Limita el nmero de conexiones nuevas que el usuario puede abrir por hora.';
$strPrivDescMaxQuestions = 'Limita el nmero de consultas que el usuario puede enviar al servidor por hora.';
$strPrivDescMaxUpdates = 'Limita el nmero de comandos que cambian cualquier tabla o base de datos que el usuario puede ejecutar por hora.';
$strPrivDescProcess3 = 'Permite destruir los procesos de otros usuarios.';
$strPrivDescProcess4 = 'Permite ver las consultas completas en la lista de procesos.';
$strPrivDescReferences = 'No tiene efecto en esta versin de MySQL.';
$strPrivDescReload = 'Permite volver a cargar los parmetros del servidor y depurar los cachs del servidor.';
$strPrivDescReplClient = 'Da el derecho al usuario para preguntar dnde estn los "esclavos / masters".';
$strPrivDescReplSlave = 'Necesario para los "esclavos" de replicacin.';
$strPrivDescSelect = 'Permite leer los datos.';
$strPrivDescShowDb = 'Concede acceso a la lista completa de bases de datos.';
$strPrivDescShutdown = 'Permite desconectar el servidor.';
$strPrivDescSuper = 'Permite la conexin, incluso si el nmero mximo de conexiones ha sido alcanzado; Necesario para la mayor parte de operaciones administrativas tales como montar parmetros de variables globales o matar "threads" de otros usuarios.';
$strPrivDescUpdate = 'Permite cambiar los datos.';
$strPrivDescUsage = 'Sin privilegios.';
$strPrivileges = 'Privilegios';
$strPrivilegesReloaded = 'Los privilegios fueron cargados nuevamente de manera exitosa.';
$strProcesslist = 'Lista de procesos';
$strPutColNames = 'Ponga los nombres de campo en la primera hilera';

$strQBE = 'Generar una consulta';
$strQBEDel = 'Borrar';
$strQBEIns = 'Insertar';
$strQueryFrame = 'Ventana de consulta';
$strQueryOnDb = 'Consulta a la base de datos <b>%s</b>:';
$strQuerySQLHistory = 'Historial-SQL';
$strQueryStatistics = '<b>Estadsticas de consulta</b>: Desde su inicio, %s consultas han sido enviadas al servidor.';
$strQueryTime = 'La consulta tard %01.4f seg';
$strQueryType = 'Tipo de consulta';
$strQueryWindowLock = 'No sobreescriba esta consulta desde fuera de la ventana';

$strReType = 'Re-escriba';
$strReadRequests = 'Lea las solicitudes';
$strReceived = 'Recibido';
$strRecords = 'Registros';
$strReferentialIntegrity = 'Compruebe la integridad referencial:';
$strRefresh = 'Actualizar';
$strRelationNotWorking = 'Las opciones adicionales para trabajar con tablas vinculadas fueron desactivadas. Para saber porqu, d clic %saqu%s.';  //Features = opciones, componentes?
$strRelationView = 'Vista de relaciones';
$strRelationalSchema = 'Esquema relacionado';
$strRelations = 'Relaciones';
$strRelationsForTable = 'RELACIONES PARA LA TABLA';
$strReloadFailed = 'El reinicio de MySQL ha fallado.';
$strReloadMySQL = 'Reinicio de MySQL';
$strReloadingThePrivileges = 'Cargando los privilegios nuevamente';
$strRemoveSelectedUsers = 'Retire a los usuarios seleccionados';
$strRenameDatabaseOK = 'La base de datos %s ha sido cambiada de nombre a %s';
$strRenameTable = 'Cambiar el nombre de la tabla a';
$strRenameTableOK = 'Tabla %s ahora se llama %s';
$strRepairTable = 'Reparar la tabla';
$strReplace = 'Reemplazar';
$strReplaceNULLBy = 'Reemplace NULL con';
$strReplaceTable = 'Reemplazar los datos de la tabla con los del archivo';
$strReset = 'Reiniciar';
$strResourceLimits = 'Lmites de recursos';
$strRevoke = 'Revocar';
$strRevokeAndDelete = 'Revocar todos los privilegios activos de los usuarios y brrelos despus.';
$strRevokeAndDeleteDescr = 'Los usuarios an tendrn el privilegio "USAGE" hasta que los privilegios se hayan vuelto a cargar.';
$strRevokeMessage = 'Ud. ha revocado los privilegios para %s';
$strRomanian = 'Rumano';
$strRowLength = 'Longitud de la fila';
$strRowSize = ' Tamao de la fila ';
$strRows = 'Filas';
$strRowsFrom = 'filas empezando de';
$strRowsModeFlippedHorizontal = 'horizontal (encabezados rotados)';
$strRowsModeHorizontal = 'horizontal';
$strRowsModeOptions = 'en modo %s y repite encabezados cada %s celdas';
$strRowsModeVertical = 'vertical';
$strRowsStatistic = 'Estadsticas de la fila';
$strRunQuery = 'Ejecutar la consulta';
$strRunSQLQuery = 'Ejecute la/s consulta/s SQL en la base de datos %s';
$strRunning = 'ejecutndose en %s';
$strRussian = 'Ruso';

$strSQL = 'SQL';
$strSQLExportCompatibility = 'Compatibilidad con exportacin SQL';
$strSQLExportType = 'Tipo de exportacin';
$strSQLOptions = 'Opciones SQL';
$strSQLParserBugMessage = 'Hay la posibilidad de que usted haya encontrado un error en el intrprete de SQL. Por favor examine cuidadosamente su consulta, y verifique que las comillas son usadas adecuadamente y hacen juego. Otra posible causa del fallo es que usted este subiendo un archivo con datos binarios por fuera del rea de texto delimitado. Intente su consulta en la interfaz de comandos de MySQL. La salida generada por el servidor de MySQL, de existir, aparece abajo, en cuyo caso puede ayudar a diagnosticar el problema. Si an tiene problemas o el intrprete falla en tanto que en la interfaz de comandos funciona, por favor reduzca la salida de su consulta de SQL a la consulta que genera el problema, y enve un reporte de error con la cadena de datos en la seccin de CORTE indicada abajo:';
$strSQLParserUserError = 'Parece haber un error en su consulta de SQL. La salida generada por el servidor de MySQL, de existir, aparece abajo, en cuyo caso puede ayudar a diagnosticar el problema.';
$strSQLQuery = 'consulta SQL';
$strSQLResult = 'Resultado SQL';
$strSQPBugInvalidIdentifer = 'El identificador no es vlido';
$strSQPBugUnclosedQuote = 'Comillas sin cerrar';
$strSQPBugUnknownPunctuation = 'Signo de puntuacin desconocido';
$strSave = 'Grabar';
$strSaveOnServer = 'Guardar en el servidor, en el directorio %s ';
$strScaleFactorSmall = 'El factor de la escala es demasiado pequeo para poner el esquema en una pgina';
$strSearch = 'Buscar';
$strSearchFormTitle = 'Buscar en la base de datos';
$strSearchInTables = 'En la(s) tabla(s):';
$strSearchNeedle = 'Palabra(s) o valor(es) a buscar (comodn: "%"):';
$strSearchOption1 = 'al menos una de estas palabras';
$strSearchOption2 = 'Todas las palabras';
$strSearchOption3 = 'La frase exacta';
$strSearchOption4 = 'como expresin regular';
$strSearchResultsFor = 'Resultados de la bsqueda por "<i>%s</i>" %s:';
$strSearchType = 'Encontrado:';
$strSecretRequired = 'El archivo de configuracin ahora necesita salvoconducto (una frase secreta) (blowfish_secret).';
$strSelectADb = 'Seleccione una base de datos';
$strSelectAll = 'Seleccione todo';
$strSelectBinaryLog = 'Seleccione el log binario para ver';
$strSelectFields = 'Seleccionar campos (al menos uno):';
$strSelectNumRows = 'en la consulta';
$strSelectTables = 'Seleccionar tablas';
$strSend = 'Enviar (genera un archivo descargable)';
$strSent = 'Enviado';
$strServer = 'Servidor';
$strServerChoice = 'Eleccin del servidor';
$strServerNotResponding = 'El servidor no est respondiendo';
$strServerStatus = 'Informacin acerca del tiempo de marcha';
$strServerStatusUptime = 'Este servidor MySQL ha estado corriendo durante %s. Se inici en %s.';
$strServerTabProcesslist = 'Procesos';
$strServerTabVariables = 'Variables';
$strServerTrafficNotes = '<b>Trfico del servidor</b>: Estas tablas las estadsticas de trfico en la red de este servidor MySQL desde su inicio.';
$strServerVars = 'Variables y parmetros del servidor';
$strServerVersion = 'Versin del servidor';
$strSessionValue = 'Valor de la sesin';
$strSetEnumVal = 'Si el tipo de campo es "enum" o "set", por favor ingrese los valores usando este formato: \'a\',\'b\',\'c\'...<br />Si alguna vez necesita poner una barra invertida("\") o una comilla simple ("\'") entre esos valores, siempre ponga una barra invertida. (Por ejemplo \'\\\\xyz\' o \'a\\\'b\').';
$strShow = 'Mostrar';
$strShowAll = 'Mostrar todo';
$strShowColor = 'Mostrar color';
$strShowDatadictAs = 'Formato del Diccionario de Datos';
$strShowFullQueries = 'Muestre las consultas enteras';
$strShowGrid = 'Mostrar cuadrcula';
$strShowPHPInfo = 'Mostrar informacin de PHP';
$strShowTableDimension = 'Mostrar la dimensin de las tablas';
$strShowTables = 'Mostrar las tablas';
$strShowThisQuery = ' Mostrar esta consulta otra vez ';
$strShowingRecords = 'Mostrando registros ';
$strSimplifiedChinese = 'Chino simplificado';
$strSingly = '(solo)';
$strSize = 'Tamao';
$strSlovak = 'Eslovaco'; 
$strSlovenian = 'Esloveno';
$strSocketProblem = '(o el socket del servidor MySQL local no est configurado correctamente)';
$strSort = 'Ordenar';
$strSortByKey = 'Organizar segn la clave';
$strSpaceUsage = 'Espacio utilizado';
$strSpanish = 'Espaol';
$strSplitWordsWithSpace = 'Palabras separadas por un espacio (" ").';
$strStatCheckTime = 'ltima revisin';
$strStatCreateTime = 'Creacin';
$strStatUpdateTime = 'ltima actualizacin';
$strStatement = 'Enunciado';
$strStatus = 'Estado actual';
$strStorageEngine = 'Motor de almacenamiento';
$strStorageEngines = 'Motores de almacenamiento';
$strStrucCSV = 'Datos CSV ';
$strStrucData = 'Estructura y datos';
$strStrucDrop = 'Aada DROP TABLE';
$strStrucExcelCSV = 'CSV para datos de MS Excel';
$strStrucNativeExcel = 'Datos de MS Excel en formato nativo';
$strStrucOnly = 'nicamente la estructura ';
$strStructPropose = 'Planteamiento de una estructura de tabla';
$strStructure = 'Estructura';
$strSubmit = 'Enviar';
$strSuccess = 'Su consulta se ejecut con xito';
$strSum = 'Nmero de filas';
$strSwedish = 'Sueco';
$strSwitchToDatabase = 'Seleccione la base de datos copiada';
$strSwitchToTable = 'Cambie (switch) a la tabla copiada';

$strTable = 'Tabla';
$strTableComments = 'Comentarios de la tabla';
$strTableEmpty = 'El nombre de la tabla est vaco!';
$strTableHasBeenDropped = 'Se ha eliminado la tabla %s';
$strTableHasBeenEmptied = 'Se ha vaciado la tabla %s';
$strTableHasBeenFlushed = 'Se ha vaciado el cach de la tabla %s';
$strTableMaintenance = 'Mantenimiento de la tabla';
$strTableOfContents = 'Tabla de contenidos';
$strTableOptions = 'Opciones de la tabla';
$strTableStructure = 'Estructura de tabla para la tabla';
$strTableType = 'Tipo de tabla';
$strTables = '%s tabla(s)';
$strTakeIt = 'tmelo';
$strTblPrivileges = 'Privilegios especficos para la tabla';
$strTextAreaLength = ' Debido a su longitud,<br /> este campo puede no ser editable ';
$strThai = 'Tailands';
$strTheContent = 'Se insert el contenido de su archivo.';
$strTheContents = 'El contenido del archivo reemplaza al contenido de la tabla seleccionada para las columnas idnticas primarias o nicas.';
$strTheTerminator = 'El separador de los campos.';
$strTheme = 'Tema / Estilo';
$strThisHost = 'Este Host';
$strThisNotDirectory = 'Esto no fue un directorio';
$strThreadSuccessfullyKilled = 'El hilo (thread) %s fue destruido exitosamente.';
$strTime = 'Tiempo';
$strToggleScratchboard = 'toggle scratchboard';
$strTotal = 'total';
$strTotalUC = 'Total';
$strTraditionalChinese = 'Chino tradicional';
$strTraditionalSpanish = 'Espaol tradicional';
$strTraffic = 'Trfico';
$strTransformation_application_octetstream__download = 'Muestre un enlace para descargar los datos binarios de un campo. La primera opcin es el nombre del archivo binario.  La segunda opcin es un nombre de campo factible de una fila de la tabla que contiene el nombre del campo. Si usted aporta una segunda opcin, necesariamente deber consignar la primera opcin a una cadena de caracteres vaca';
$strTransformation_image_jpeg__inline = 'Muestra un thumbnail que puede abrirse mediante un clic; opciones: width, height en pxeles (mantiene la proporcin original)';
$strTransformation_image_jpeg__link = 'Muestra un enlace a esta imagen (blob download directo, i.e.).';
$strTransformation_image_png__inline = 'Ver imagen/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Toma un campo TIME, TIMESTAMP o DATETIME y lo formatea usando su formato de fechas local. La primera opcin es el offset (en horas) que se aadir al timestamp (Predeterminado: 0). La segunda opcin es un dateformat diferente de acuerdo con los parmetros disponibles para el strftime() del PHP.';
$strTransformation_text_plain__external = 'LINUX SOLAMENTE: Ejecuta una aplicacin externa y alimenta el fielddata mediante input estndar. Retorna el output estndar de la aplicacin. El predeterminado es Tidy, para mostrar cdigo HTML agradable para la impresin. Por razones de seguridad, debe editar manualmente el archivo libraries/transformations/text_plain__external.inc.php e insertar las herramientas que permitir se ejecuten. La primera opcin ser el nmero del programa que querr utilizar y la segunda opcin son los parmetros para el programa. El tercer parmetro, de ser 1 convertir el output usando htmlspecialchars() (el predeterminado es 1). Un cuarto parmetro, de ser 1 pondr un NOWRAP a la celda de contenido para que todo el output se muestre sin reformatear (Predeterminado 1)';
$strTransformation_text_plain__formatted = 'Mantiene el formato original del campo. No se puede hacer Escape.';
$strTransformation_text_plain__imagelink = 'Muestra una imagen y un enlace, el campo contiene el nombre del archivo; la primera opcin es un prefijo como "http://dominio.com/", la segunda opcin es el ancho en pxeles, el tercero es el alto.';
$strTransformation_text_plain__link = 'Muestra un enlace, el campo contiene el nombre del archivo; la primera opcin es un prefijo como "http://dominio.com/", la segunda opcin es un ttulo para el enlace.';
$strTransformation_text_plain__substr = 'Muestra una parte de una cadena de caracteres. La primera opcin es el nmero de caracteres a pasar por alto desde el principio de la cadena de caracteres (Predeterminado: 0). La segunda opcin es el nmero de caracteres a mostrar (Predeterminado: hasta el final de la cadena de caracteres). La tercera opcin es la cadena de caracteres a adjuntar y/o anteponer cuando haya truncamiento (Predeterminado: "...").';
$strTransformation_text_plain__unformatted = 'Muestra el cdigo HTML como entidades HTML. No se muestra formato HTML.';
$strTruncateQueries = 'Trunque las consultas que ya se han mostrado';
$strTurkish = 'Turco';
$strType = 'Tipo';

$strUkrainian = 'Ucraniano';
$strUncheckAll = 'Desmarcar todos';
$strUnicode = 'Unicode';
$strUnique = 'nico';
$strUnknown = 'desconocido';
$strUnselectAll = 'Deseleccione todo';
$strUpdComTab = 'Para actualizar su tabla Columna_comentarios (Column_comments), por favor revise la documentacin';
$strUpdatePrivMessage = 'Ud. ha actualizado los privilegios para %s.';
$strUpdateProfileMessage = 'Se actualiz el perfil.';
$strUpdateQuery = 'Modificar la consulta';
$strUpgrade = 'Usted debera actualizar su %s a la versin %s o ms reciente.';
$strUsage = 'Uso';
$strUseBackquotes = 'Usar "backquotes" con tablas y nombres de campo';
$strUseHostTable = 'Use la tabla Anfitrin (Host)';
$strUseTabKey = 'Use la tecla TAB para saltar de un valor a otro, o CTRL+flechas para moverse a cualquier parte';
$strUseTables = 'Usar tablas';
$strUseTextField = 'Use el campo de texto';
$strUseThisValue = 'Use este valor';
$strUser = 'Usuario';
$strUserAlreadyExists = 'El usuario %s ya existe!';
$strUserEmpty = 'El nombre de usuario est vaco!';
$strUserName = 'Nombre de usuario';
$strUserNotFound = 'El usuario que seleccion no fue hallado en la tabla de privilegios.';
$strUserOverview = 'Vista global del usuario';
$strUsersDeleted = 'Los usuarios seleccionados fueron borrados exitosamente.';
$strUsersHavingAccessToDb = 'Usuarios con acceso a &quot;%s&quot;';

$strValidateSQL = 'Validar el SQL';
$strValidatorError = 'El validador de SQL no pudo inicializarse. Por favor revise si ha instalado las extensiones php necesarias, como fueron descritas en la %sdocumentacin%s.';
$strValue = 'Valor';
$strVar = 'Variable';
$strVersionInformation = 'Acerca de esta versin';
$strView = 'Visualizar';
$strViewDump = 'Mostrar el volcado esquema de la tabla';
$strViewDumpDB = 'Ver el volcado esquema de la base de datos';
$strViewDumpDatabases = 'Ver el dump (schema) de la base de datos';
$strViewHasBeenDropped = 'Se descart el modo de visualizacin %s';

$strWebServerUploadDirectory = 'directorio en el servidor web para subir los archivos';
$strWebServerUploadDirectoryError = 'No est disponible el directorio que usted habilit para subir las tareas';
$strWelcome = 'Bienvenido a %s';
$strWestEuropean = 'Europea occidental';
$strWildcard = 'comodn';
$strWindowNotFound = 'La ventana del navegador no pudo actualizarse. Quiz cerr la ventana principal o su navegador est bloqueando las actualizaciones en ventanas mltiples debido a sus parmetros de seguridad.';
$strWithChecked = 'Con marca:';
$strWriteRequests = 'Escriba las solicitudes';
$strWritingCommentNotPossible = 'No fue posible escribir el comentario';
$strWritingRelationNotPossible = 'No fue posible escribir la relacin';
$strWrongUser = 'Usuario/contrasea equivocado. Acceso denegado.';

$strXML = 'XML';

$strYes = 'S';

$strZeroRemovesTheLimit = 'Nota: si cambia los parmetros de estas opciones a 0 (cero), remueve el lmite.';
$strZip = '"comprimido con zip"';

// To translate:

$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate

$strRoutines = 'Routines';  //to translate

$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
?>
